# coding=utf8

# Copyright 2018 JDCLOUD.COM
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import abc

FATAL = 0
ERROR = 1
WARN = 2
INFO = 3


class Logger(object):

    def __init__(self, level):
        self.__level = level

    @abc.abstractmethod
    def log(self, level, message):
        if level <= self.__level:
            print(message)


DEFAULT_LOGGER = Logger(INFO)


def get_default_logger():
    return DEFAULT_LOGGER
